@@ -1,4 +1,4 @@
-/* $Id: dat.c,v 1.18 2007/12/13 02:53:30 rikster5 Exp $ */
+/* $Id: dat.c,v 1.21 2008/06/19 04:12:07 rikster5 Exp $ */
 
 /*******************************************************************************
  * dat.c
@@ -19,7 +19,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
-
 /*
  * Thanks to nseessle@mail.hh.provi.de
  * http://ourworld.compuserve.com/homepages/nseessle/frames/pilot/dat_e.htm
@@ -29,20 +28,18 @@
  * For their descriptions of the dat formats.
  */
 
+/********************************* Includes ***********************************/
 #include "config.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
-#ifdef HAVE_LOCALE_H
-#include <locale.h>
-#endif
-#include "log.h"
-#include "utils.h"
+
 #include "i18n.h"
+#include "utils.h"
+#include "log.h"
 
-#define JPILOT_DEBUGno
-
+/********************************* Constants **********************************/
 #define DAT_STATUS_ADD     0x01
 #define DAT_STATUS_UPDATE  0x02
 #define DAT_STATUS_DELETE  0x04
@@ -51,6 +48,7 @@
 /* I made this one up for a bit to store the private flag */
 #define DAT_STATUS_PRIVATE 0x10
 
+/* Repeat types */
 #define DAILY           1
 #define WEEKLY          2
 #define MONTHLY_BY_DAY  3
@@ -58,7 +56,17 @@
 #define YEARLY_BY_DATE  5
 #define YEARLY_BY_DAY   6
 
+/* DAT field types */
+#define DAT_TYPE_INTEGER 1
+#define DAT_TYPE_CSTRING 5
+#define DAT_TYPE_DATE    3
+#define DAT_TYPE_BOOLEAN 6
+#define DAT_TYPE_BITFLAG 7
+#define DAT_TYPE_REPEAT  8
 
+/* #define JPILOT_DEBUG */
+
+/****************************** Prototypes ************************************/
 #ifdef JPILOT_DEBUG
 static int print_date(int palm_date);
 #endif
@@ -70,6 +78,7 @@ struct field {
    char *str;
 };
 
+/****************************** Main Code *************************************/
 static int x86_short(unsigned char *str)
 {
    return str[1] * 0x100 + str[0];
@@ -80,7 +89,6 @@ static long x86_long(unsigned char *str)
    return str[3]*0x1000000 + str[2]*0x0010000 + str[1]*0x0000100 + str[0];
 }
 
-
 /* Returns the length of the CString read */
 static int get_CString(FILE *in, char **PStr)
 {
@@ -129,23 +137,23 @@ static int get_categories(FILE *in, struct CategoryAppInfo *ai)
    ai->lastUniqueID=0;
 
    for (i=0; i<count; i++) {
-      /* This is the category index */
+      /* category index */
       fread(str_long, 4, 1, in);
 
-      /* This is the category ID */
+      /* category ID */
       fread(str_long, 4, 1, in);
       ai->ID[i] = x86_long(str_long);
 
-      /* This is the category dirty flag */
+      /* category dirty flag */
       fread(str_long, 4, 1, in);
 
-      /* Long Category Name */
+      /* long category name */
       get_CString(in, &PStr);
       strncpy(ai->name[i], PStr, 16);
       ai->name[i][15]='\0';
       free(PStr);
 
-      /* Short Category Name */
+      /* short category name */
       get_CString(in, &PStr);
       free(PStr);
    }
@@ -212,7 +220,7 @@ int get_repeat(FILE *in, struct Appointment *appt)
    }
 
    if (s==0xFFFF) {
-      /* We have a Class entry here */
+      /* Class entry here */
       fread(str_short, 2, 1, in);
       s = x86_short(str_short);
 #ifdef JPILOT_DEBUG
@@ -240,7 +248,7 @@ int get_repeat(FILE *in, struct Appointment *appt)
    }
 #ifdef JPILOT_DEBUG
    printf("repeatType=%d ", repeat_type);
-   switch(repeat_type) {
+   switch (repeat_type) {
     case DAILY:
       printf("Daily\n");
       break;
@@ -297,7 +305,7 @@ int get_repeat(FILE *in, struct Appointment *appt)
    printf("First Day of Week = %d\n", l);
 #endif
 
-   switch(repeat_type) {
+   switch (repeat_type) {
     case DAILY:
       fread(str_long, 4, 1, in);
       l = x86_long(str_long);
@@ -366,7 +374,6 @@ int get_repeat(FILE *in, struct Appointment *appt)
    return EXIT_SUCCESS;
 }
 
-
 #ifdef JPILOT_DEBUG
 static int print_date(int palm_date)
 {
@@ -374,7 +381,7 @@ static int print_date(int palm_date)
    struct tm *now;
    char text[256];
 
-   t = palm_date;/* - 20828448800; */
+   t = palm_date;   /* - 20828448800; */
    now = localtime(&t);
    strftime(text, sizeof(text), "%02m/%02d/%Y %02H:%02M:%02S", now);
    printf("%s\n", text);
@@ -387,12 +394,15 @@ static int print_date(int palm_date)
 int print_field(struct field *f)
 {
 
-   switch(f->type) {
+   switch (f->type) {
     case DAT_TYPE_INTEGER:
       printf("%d\n", f->i);
       break;
     case DAT_TYPE_CSTRING:
-      printf("%s\n", f->str);
+      if (f->str)
+	 printf("%s\n", f->str);
+      else
+	 printf("\n");
       break;
     case DAT_TYPE_BOOLEAN:
       if (f->i) {
@@ -427,14 +437,13 @@ int get_field(FILE *in, struct field *f)
    f->type=type;
    f->str=NULL;
 
-   switch(type) {
+   switch (type) {
     case DAT_TYPE_INTEGER:
       fread(str_long, 4, 1, in);
       f->i = x86_long(str_long);
       break;
     case DAT_TYPE_CSTRING:
-      /* padding */
-      fseek(in, 4, SEEK_CUR);
+      fseek(in, 4, SEEK_CUR); /* padding */
       get_CString(in, &PStr);
       f->str = PStr;
       break;
@@ -560,14 +569,12 @@ int dat_read_header(FILE *in,
       jp_logf(JP_LOG_WARN, _("Unknown format, file has wrong schema\n"));
       jp_logf(JP_LOG_WARN, _("File schema is:"));
       for (i=0; i<(*field_count)*2; i++) {
-	 jp_logf(JP_LOG_WARN, " %02d", (char)filler[i]);
+	 jp_logf(JP_LOG_WARN, " %02d\n", (char)filler[i]);
       }
-      jp_logf(JP_LOG_WARN, "\n");
-      jp_logf(JP_LOG_WARN, _("It should be:  "));
+      jp_logf(JP_LOG_WARN, _("It should be:"));
       for (i=0; i<(*field_count)*2; i++) {
-	 jp_logf(JP_LOG_WARN, " %02d", (char)schema[i]);
+	 jp_logf(JP_LOG_WARN, " %02d\n", (char)schema[i]);
       }
-      jp_logf(JP_LOG_WARN, "\n");
       return EXIT_FAILURE;
    }
 
@@ -716,6 +723,7 @@ int dat_get_appointments(FILE *in, AppointmentList **alist, struct CategoryAppIn
       }
       /* Duration */
       /* what is duration? (repeatForever?) */
+
       /* Note */
       if (fa[4].str) {
 	 temp_alist->mappt.appt.note=fa[4].str;
